<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance_commission');

// 记录访问日志
record_log('访问OTA佣金管理页面');

// 生成结算批次号
function generate_settlement_batch()
{
    return 'SET' . date('YmdHis') . rand(100, 999);
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 结算单个佣金
    if ($_POST['action'] == 'settle') {
        $commission_id = isset($_POST['commission_id']) ? intval($_POST['commission_id']) : 0;

        if ($commission_id <= 0) {
            $error = '无效的佣金ID！';
        } else {
            try {
                // 获取佣金信息，确保状态为未结算
                $stmt = $pdo->prepare("
                    SELECT c.*, o.channel_name, b.booking_no, b.guest_name
                    FROM finance_commissions c
                    JOIN ota_channels o ON c.channel_id = o.id
                    JOIN booking_orders b ON c.booking_id = b.id
                    WHERE c.id = ? AND c.settlement_status = 1
                ");
                $stmt->execute([$commission_id]);
                $commission = $stmt->fetch();

                if (!$commission) {
                    $error = '佣金记录不存在或已结算！';
                } else {
                    $settlement_batch = generate_settlement_batch();

                    $stmt = $pdo->prepare("
                        UPDATE finance_commissions 
                        SET settlement_status = 2, 
                            settlement_time = NOW(), 
                            settlement_batch = ? 
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([
                        $settlement_batch,
                        $commission_id
                    ]);

                    if ($result) {
                        record_log("结算佣金：渠道 {$commission['channel_name']}，订单 {$commission['booking_no']}，金额 {$commission['commission_amount']}");
                        $success = '佣金结算成功！';
                    } else {
                        $error = '佣金结算失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 批量结算佣金
    elseif ($_POST['action'] == 'batch_settle') {
        $commission_ids = isset($_POST['commission_ids']) ? $_POST['commission_ids'] : [];

        if (empty($commission_ids)) {
            $error = '请选择需要结算的佣金记录！';
        } else {
            try {
                $pdo->beginTransaction();

                $settlement_batch = generate_settlement_batch();
                $placeholders = implode(',', array_fill(0, count($commission_ids), '?'));

                // 确认所有ID的佣金都未结算
                $stmt = $pdo->prepare("
                    SELECT COUNT(*) 
                    FROM finance_commissions 
                    WHERE id IN ({$placeholders}) AND settlement_status != 1
                ");
                $stmt->execute($commission_ids);
                $invalid_count = $stmt->fetchColumn();

                if ($invalid_count > 0) {
                    $error = '选择的佣金中有 ' . $invalid_count . ' 条已结算或不存在！';
                    $pdo->rollBack();
                } else {
                    // 更新结算状态
                    $stmt = $pdo->prepare("
                        UPDATE finance_commissions 
                        SET settlement_status = 2, 
                            settlement_time = NOW(), 
                            settlement_batch = ? 
                        WHERE id IN ({$placeholders}) AND settlement_status = 1
                    ");

                    $params = array_merge([$settlement_batch], $commission_ids);
                    $result = $stmt->execute($params);

                    // 获取受影响的行数
                    $affected_rows = $stmt->rowCount();

                    if ($result && $affected_rows > 0) {
                        $pdo->commit();
                        record_log("批量结算佣金：结算批次 {$settlement_batch}，共 {$affected_rows} 条");
                        $success = "成功结算 {$affected_rows} 条佣金记录！批次号：{$settlement_batch}";
                    } else {
                        $pdo->rollBack();
                        $error = '佣金批量结算失败！';
                    }
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选条件
$channel_id = isset($_GET['channel_id']) ? intval($_GET['channel_id']) : 0;
$settlement_status = isset($_GET['settlement_status']) ? intval($_GET['settlement_status']) : 0;
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$settlement_batch = isset($_GET['settlement_batch']) ? trim($_GET['settlement_batch']) : '';

// 构建查询条件
$where_clauses = [];
$params = [];

$where_clauses[] = "b.arrival_date BETWEEN ? AND ?";
$params[] = $start_date;
$params[] = $end_date;

if ($channel_id > 0) {
    $where_clauses[] = "c.channel_id = ?";
    $params[] = $channel_id;
}

if ($settlement_status > 0) {
    $where_clauses[] = "c.settlement_status = ?";
    $params[] = $settlement_status;
}

if (!empty($settlement_batch)) {
    $where_clauses[] = "c.settlement_batch = ?";
    $params[] = $settlement_batch;
}

$where_sql = implode(" AND ", $where_clauses);

// 获取所有OTA渠道
try {
    $stmt = $pdo->query("SELECT id, channel_name FROM ota_channels WHERE status = 1 ORDER BY id");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取OTA渠道列表失败：' . $e->getMessage();
    $channels = [];
}

// 获取佣金列表
try {
    $sql = "
        SELECT c.*, o.channel_name, o.channel_code, b.booking_no, b.guest_name, 
               b.arrival_date, b.departure_date
        FROM finance_commissions c
        JOIN ota_channels o ON c.channel_id = o.id
        JOIN booking_orders b ON c.booking_id = b.id
        WHERE {$where_sql}
        ORDER BY c.settlement_status ASC, b.arrival_date DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $commissions = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取佣金列表失败：' . $e->getMessage();
    $commissions = [];
}

// 计算未结算金额和已结算金额
$total_unsettled = 0;
$total_settled = 0;
$total_commissions = 0;

foreach ($commissions as $commission) {
    if ($commission['settlement_status'] == 1) {
        $total_unsettled += $commission['commission_amount'];
    } else {
        $total_settled += $commission['commission_amount'];
    }
    $total_commissions += $commission['commission_amount'];
}

// 获取所有结算批次
try {
    $stmt = $pdo->query("
        SELECT settlement_batch, COUNT(*) as count, SUM(commission_amount) as total_amount, 
               MIN(settlement_time) as settlement_time
        FROM finance_commissions
        WHERE settlement_status = 2 AND settlement_batch IS NOT NULL
        GROUP BY settlement_batch
        ORDER BY settlement_time DESC
        LIMIT 20
    ");
    $settlement_batches = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取结算批次列表失败：' . $e->getMessage();
    $settlement_batches = [];
}

// 判断是否查看详情
$view_commission_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 判断是否显示结算批次详情
$view_batch = isset($_GET['view_batch']) ? trim($_GET['view_batch']) : '';
$batch_commissions = [];

if (!empty($view_batch)) {
    try {
        $stmt = $pdo->prepare("
            SELECT c.*, o.channel_name, o.channel_code, b.booking_no, b.guest_name, 
                   b.arrival_date, b.departure_date
            FROM finance_commissions c
            JOIN ota_channels o ON c.channel_id = o.id
            JOIN booking_orders b ON c.booking_id = b.id
            WHERE c.settlement_batch = ?
            ORDER BY c.settlement_time DESC
        ");
        $stmt->execute([$view_batch]);
        $batch_commissions = $stmt->fetchAll();

        // 获取批次汇总信息
        $stmt = $pdo->prepare("
            SELECT COUNT(*) as count, SUM(commission_amount) as total_amount, 
                   MIN(settlement_time) as settlement_time
            FROM finance_commissions
            WHERE settlement_batch = ?
        ");
        $stmt->execute([$view_batch]);
        $batch_summary = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取结算批次详情失败：' . $e->getMessage();
        $batch_commissions = [];
        $batch_summary = null;
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>OTA佣金管理</title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .summary-box {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .summary-item {
            flex: 1;
            min-width: 200px;
            background: #f8f9fa;
            padding: 15px;
            border-radius: 4px;
            border: 1px solid #ddd;
            text-align: center;
        }

        .summary-label {
            display: block;
            font-weight: bold;
            margin-bottom: 5px;
            color: #666;
        }

        .summary-value {
            display: block;
            font-size: 24px;
            font-weight: bold;
            color: #4CAF50;
        }

        .summary-value.expense {
            color: #dc3545;
        }

        .tab-container {
            margin-bottom: 20px;
        }

        .tab-buttons {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 15px;
        }

        .tab-button {
            padding: 8px 16px;
            background: #f8f9fa;
            border: 1px solid #ddd;
            border-bottom: none;
            margin-right: 5px;
            border-radius: 4px 4px 0 0;
            cursor: pointer;
        }

        .tab-button.active {
            background: #4CAF50;
            color: white;
            border-color: #4CAF50;
        }

        .batch-item {
            background: #f8f9fa;
            padding: 12px;
            margin-bottom: 10px;
            border-radius: 4px;
            border: 1px solid #ddd;
        }

        .batch-header {
            display: flex;
            justify-content: space-between;
            margin-bottom: 8px;
        }

        .batch-title {
            font-weight: bold;
            font-size: 16px;
        }

        .batch-info {
            display: flex;
            gap: 20px;
        }

        .batch-info span {
            color: #666;
        }

        .checkbox-column {
            width: 30px;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>OTA佣金管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; OTA佣金管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 数据概览 -->
            <div class="summary-box">
                <div class="summary-item">
                    <span class="summary-label">未结算佣金</span>
                    <span class="summary-value expense">￥<?php echo number_format($total_unsettled, 2); ?></span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">已结算佣金</span>
                    <span class="summary-value">￥<?php echo number_format($total_settled, 2); ?></span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">佣金总额</span>
                    <span class="summary-value">￥<?php echo number_format($total_commissions, 2); ?></span>
                </div>
            </div>

            <?php if (!empty($view_batch)): ?>
                <!-- 结算批次详情 -->
                <div class="action-bar">
                    <a href="commission.php" class="btn btn-secondary">返回佣金列表</a>
                </div>

                <h3>结算批次详情 - <?php echo $view_batch; ?></h3>
                <div class="batch-summary">
                    <p><strong>结算时间：</strong> <?php echo date('Y-m-d H:i:s', strtotime($batch_summary['settlement_time'])); ?></p>
                    <p><strong>结算笔数：</strong> <?php echo $batch_summary['count']; ?> 笔</p>
                    <p><strong>结算金额：</strong> ￥<?php echo number_format($batch_summary['total_amount'], 2); ?></p>
                </div>

                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>渠道</th>
                                <th>订单号</th>
                                <th>客人</th>
                                <th>入住日期</th>
                                <th>订单金额(元)</th>
                                <th>佣金比例(%)</th>
                                <th>佣金金额(元)</th>
                                <th>结算时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($batch_commissions) > 0): ?>
                                <?php foreach ($batch_commissions as $commission): ?>
                                    <tr>
                                        <td><?php echo $commission['id']; ?></td>
                                        <td><?php echo $commission['channel_name']; ?> (<?php echo $commission['channel_code']; ?>)</td>
                                        <td><?php echo $commission['booking_no']; ?></td>
                                        <td><?php echo $commission['guest_name']; ?></td>
                                        <td><?php echo $commission['arrival_date']; ?></td>
                                        <td><?php echo number_format($commission['amount'], 2); ?></td>
                                        <td><?php echo $commission['commission_rate']; ?>%</td>
                                        <td><?php echo number_format($commission['commission_amount'], 2); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($commission['settlement_time'])); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="9" class="text-center">暂无结算记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

            <?php else: ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="channel_id">OTA渠道：</label>
                                <select id="channel_id" name="channel_id">
                                    <option value="0">全部渠道</option>
                                    <?php foreach ($channels as $channel): ?>
                                        <option value="<?php echo $channel['id']; ?>" <?php echo $channel_id == $channel['id'] ? 'selected' : ''; ?>><?php echo $channel['channel_name']; ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="settlement_status">结算状态：</label>
                                <select id="settlement_status" name="settlement_status">
                                    <option value="0" <?php echo $settlement_status == 0 ? 'selected' : ''; ?>>全部</option>
                                    <option value="1" <?php echo $settlement_status == 1 ? 'selected' : ''; ?>>未结算</option>
                                    <option value="2" <?php echo $settlement_status == 2 ? 'selected' : ''; ?>>已结算</option>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="settlement_batch">结算批次：</label>
                                <select id="settlement_batch" name="settlement_batch">
                                    <option value="">全部批次</option>
                                    <?php foreach ($settlement_batches as $batch): ?>
                                        <option value="<?php echo $batch['settlement_batch']; ?>" <?php echo $settlement_batch == $batch['settlement_batch'] ? 'selected' : ''; ?>>
                                            <?php echo $batch['settlement_batch']; ?> (<?php echo date('Y-m-d', strtotime($batch['settlement_time'])); ?>, <?php echo $batch['count']; ?>笔)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                            </div>
                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                            </div>
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="commission.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- 佣金列表 -->
                <h3>佣金列表</h3>
                <div class="action-bar">
                    <?php if ($total_unsettled > 0): ?>
                        <button id="batchSettleBtn" class="btn btn-success">批量结算</button>
                    <?php endif; ?>
                </div>

                <form id="batchSettleForm" method="post" action="" onsubmit="return confirmBatchSettle()">
                    <input type="hidden" name="action" value="batch_settle">

                    <div class="data-list">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th class="checkbox-column">
                                        <?php if ($total_unsettled > 0): ?>
                                            <input type="checkbox" id="selectAll" onclick="toggleAllCheckboxes()">
                                        <?php endif; ?>
                                    </th>
                                    <th>ID</th>
                                    <th>渠道</th>
                                    <th>订单号</th>
                                    <th>客人</th>
                                    <th>入住日期</th>
                                    <th>订单金额(元)</th>
                                    <th>佣金比例(%)</th>
                                    <th>佣金金额(元)</th>
                                    <th>结算状态</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (count($commissions) > 0): ?>
                                    <?php foreach ($commissions as $commission): ?>
                                        <tr>
                                            <td class="checkbox-column">
                                                <?php if ($commission['settlement_status'] == 1): ?>
                                                    <input type="checkbox" name="commission_ids[]" value="<?php echo $commission['id']; ?>" class="commission-checkbox">
                                                <?php endif; ?>
                                            </td>
                                            <td><?php echo $commission['id']; ?></td>
                                            <td><?php echo $commission['channel_name']; ?> (<?php echo $commission['channel_code']; ?>)</td>
                                            <td><?php echo $commission['booking_no']; ?></td>
                                            <td><?php echo $commission['guest_name']; ?></td>
                                            <td><?php echo $commission['arrival_date']; ?></td>
                                            <td><?php echo number_format($commission['amount'], 2); ?></td>
                                            <td><?php echo $commission['commission_rate']; ?>%</td>
                                            <td><?php echo number_format($commission['commission_amount'], 2); ?></td>
                                            <td>
                                                <?php if ($commission['settlement_status'] == 1): ?>
                                                    <span class="status-warning">未结算</span>
                                                <?php else: ?>
                                                    <span class="status-active">已结算</span>
                                                    <br>
                                                    <a href="commission.php?view_batch=<?php echo $commission['settlement_batch']; ?>" class="small-link">
                                                        <?php echo $commission['settlement_batch']; ?>
                                                    </a>
                                                <?php endif; ?>
                                            </td>
                                            <td>
                                                <?php if ($commission['settlement_status'] == 1): ?>
                                                    <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要结算此佣金吗？');">
                                                        <input type="hidden" name="action" value="settle">
                                                        <input type="hidden" name="commission_id" value="<?php echo $commission['id']; ?>">
                                                        <button type="submit" class="btn btn-sm btn-primary">结算</button>
                                                    </form>
                                                <?php endif; ?>

                                                <a href="commission.php?view=<?php echo $commission['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                            </td>
                                        </tr>
                                        <?php if ($view_commission_id == $commission['id']): ?>
                                            <tr>
                                                <td colspan="11" class="details-row">
                                                    <div class="commission-details">
                                                        <div class="detail-group">
                                                            <h4>佣金详情</h4>
                                                            <p><strong>渠道：</strong> <?php echo $commission['channel_name']; ?> (<?php echo $commission['channel_code']; ?>)</p>
                                                            <p><strong>订单号：</strong> <?php echo $commission['booking_no']; ?></p>
                                                            <p><strong>客人：</strong> <?php echo $commission['guest_name']; ?></p>
                                                            <p><strong>入住日期：</strong> <?php echo $commission['arrival_date']; ?></p>
                                                            <p><strong>离店日期：</strong> <?php echo $commission['departure_date']; ?></p>
                                                            <p><strong>订单金额：</strong> ￥<?php echo number_format($commission['amount'], 2); ?></p>
                                                            <p><strong>佣金比例：</strong> <?php echo $commission['commission_rate']; ?>%</p>
                                                            <p><strong>佣金金额：</strong> ￥<?php echo number_format($commission['commission_amount'], 2); ?></p>
                                                            <p><strong>结算状态：</strong>
                                                                <?php echo $commission['settlement_status'] == 1 ? '未结算' : '已结算'; ?>
                                                            </p>
                                                            <?php if ($commission['settlement_status'] == 2): ?>
                                                                <p><strong>结算时间：</strong> <?php echo date('Y-m-d H:i:s', strtotime($commission['settlement_time'])); ?></p>
                                                                <p><strong>结算批次：</strong> <?php echo $commission['settlement_batch']; ?></p>
                                                            <?php endif; ?>
                                                        </div>
                                                    </div>
                                                </td>
                                            </tr>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="11" class="text-center">暂无佣金记录</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </form>

                <!-- 结算批次列表 -->
                <h3>最近结算批次</h3>
                <div class="batch-list">
                    <?php if (count($settlement_batches) > 0): ?>
                        <?php foreach ($settlement_batches as $batch): ?>
                            <div class="batch-item">
                                <div class="batch-header">
                                    <div class="batch-title">
                                        <a href="commission.php?view_batch=<?php echo $batch['settlement_batch']; ?>">
                                            <?php echo $batch['settlement_batch']; ?>
                                        </a>
                                    </div>
                                    <div>
                                        <a href="commission.php?view_batch=<?php echo $batch['settlement_batch']; ?>" class="btn btn-sm btn-details">查看明细</a>
                                    </div>
                                </div>
                                <div class="batch-info">
                                    <span><strong>结算时间：</strong> <?php echo date('Y-m-d H:i:s', strtotime($batch['settlement_time'])); ?></span>
                                    <span><strong>结算笔数：</strong> <?php echo $batch['count']; ?> 笔</span>
                                    <span><strong>结算金额：</strong> ￥<?php echo number_format($batch['total_amount'], 2); ?></span>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <p class="text-center">暂无结算批次记录</p>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function toggleAllCheckboxes() {
            var checkboxes = document.getElementsByClassName('commission-checkbox');
            var selectAllCheckbox = document.getElementById('selectAll');

            for (var i = 0; i < checkboxes.length; i++) {
                checkboxes[i].checked = selectAllCheckbox.checked;
            }
        }

        function confirmBatchSettle() {
            var checkboxes = document.getElementsByClassName('commission-checkbox');
            var selectedCount = 0;

            for (var i = 0; i < checkboxes.length; i++) {
                if (checkboxes[i].checked) {
                    selectedCount++;
                }
            }

            if (selectedCount === 0) {
                alert('请选择至少一条佣金记录进行结算！');
                return false;
            }

            return confirm('确定要结算选中的 ' + selectedCount + ' 条佣金记录吗？');
        }

        document.getElementById('batchSettleBtn').addEventListener('click', function() {
            document.getElementById('batchSettleForm').submit();
        });
    </script>
</body>

</html>