<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('room');

// 记录访问日志
record_log('访问客房清洁管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加清洁任务
    if ($_POST['action'] == 'add') {
        $room_id = isset($_POST['room_id']) ? intval($_POST['room_id']) : 0;
        $task_type = isset($_POST['task_type']) ? trim($_POST['task_type']) : '常规清洁';
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';
        $priority = isset($_POST['priority']) ? intval($_POST['priority']) : 1;
        $assigned_to = isset($_POST['assigned_to']) ? trim($_POST['assigned_to']) : '';

        if ($room_id <= 0) {
            $error = '请选择房间！';
        } else {
            try {
                // 获取房间号用于日志记录
                $stmt = $pdo->prepare("SELECT room_number FROM room_info WHERE id = ?");
                $stmt->execute([$room_id]);
                $room = $stmt->fetch();

                if (!$room) {
                    $error = '选择的房间不存在！';
                } else {
                    $stmt = $pdo->prepare("
                        INSERT INTO room_cleaning (
                            room_id, clean_date, status, cleaner_id, remarks
                        ) VALUES (?, CURDATE(), 1, ?, ?)
                    ");
                    $result = $stmt->execute([
                        $room_id,
                        !empty($assigned_to) ? $assigned_to : null,
                        $description
                    ]);

                    if ($result) {
                        record_log("为房间 {$room['room_number']} 添加清洁任务");

                        // 同时更新房间状态为清洁中
                        $stmt = $pdo->prepare("UPDATE room_info SET status = 4 WHERE id = ?");
                        $stmt->execute([$room_id]);

                        $success = '清洁任务添加成功！';
                    } else {
                        $error = '清洁任务添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 更新任务状态
    elseif ($_POST['action'] == 'update_status') {
        $task_id = isset($_POST['task_id']) ? intval($_POST['task_id']) : 0;
        $new_status = isset($_POST['status']) ? intval($_POST['status']) : 0;
        $completion_notes = isset($_POST['completion_notes']) ? trim($_POST['completion_notes']) : '';

        if ($task_id <= 0 || $new_status <= 0 || $new_status > 3) {
            $error = '任务ID和状态必须提供且有效！';
        } else {
            try {
                // 获取当前任务信息用于日志记录
                $stmt = $pdo->prepare("
                    SELECT t.id, r.room_number, r.id as room_id
                    FROM room_cleaning t
                    JOIN room_info r ON t.room_id = r.id
                    WHERE t.id = ?
                ");
                $stmt->execute([$task_id]);
                $task = $stmt->fetch();

                if (!$task) {
                    $error = '任务不存在！';
                } else {
                    // 根据新状态决定是否设置完成时间
                    $complete_time = ($new_status == 3) ? 'complete_time = NOW(),' : '';

                    // 更新备注
                    $remarks_update = '';
                    if (!empty($completion_notes)) {
                        $remarks_update = "remarks = CONCAT(IFNULL(remarks, ''), '\n--- 完成备注 ---\n', :notes),";
                    }

                    $sql = "
                        UPDATE room_cleaning 
                        SET status = :status, 
                            $complete_time
                            $remarks_update
                            cleaner_id = CASE WHEN cleaner_id IS NULL AND :status > 1 THEN :user_id ELSE cleaner_id END
                        WHERE id = :task_id
                    ";

                    $stmt = $pdo->prepare($sql);
                    $stmt->bindValue(':status', $new_status, PDO::PARAM_INT);
                    $stmt->bindValue(':task_id', $task_id, PDO::PARAM_INT);
                    $stmt->bindValue(':user_id', isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null, PDO::PARAM_INT);

                    if (!empty($completion_notes)) {
                        $stmt->bindValue(':notes', $completion_notes, PDO::PARAM_STR);
                    }

                    $result = $stmt->execute();

                    if ($result) {
                        $status_texts = [1 => '待处理', 2 => '处理中', 3 => '已完成'];
                        record_log("更新房间 {$task['room_number']} 的清洁任务状态为 {$status_texts[$new_status]}");

                        // 如果任务完成，更新房间状态为可用
                        if ($new_status == 3) {
                            try {
                                $stmt = $pdo->prepare("UPDATE room_info SET status = 1 WHERE id = ? AND status = 4");
                                $stmt->execute([$task['room_id']]);
                                record_log("房间 {$task['room_number']} 清洁完成，状态已更新为可用");
                            } catch (PDOException $e) {
                                // 记录错误但不中断流程
                                error_log("更新房间状态失败：" . $e->getMessage());
                            }
                        }

                        $success = '任务状态更新成功！';
                    } else {
                        $error = '任务状态更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除清洁任务
    elseif ($_POST['action'] == 'delete') {
        $task_id = isset($_POST['task_id']) ? intval($_POST['task_id']) : 0;

        if ($task_id <= 0) {
            $error = '无效的任务ID！';
        } else {
            try {
                // 获取任务信息用于日志记录
                $stmt = $pdo->prepare("
                    SELECT r.room_number 
                    FROM room_cleaning t
                    JOIN room_info r ON t.room_id = r.id
                    WHERE t.id = ?
                ");
                $stmt->execute([$task_id]);
                $task = $stmt->fetch();

                if (!$task) {
                    $error = '任务不存在！';
                } else {
                    $stmt = $pdo->prepare("DELETE FROM room_cleaning WHERE id = ?");
                    $result = $stmt->execute([$task_id]);

                    if ($result) {
                        record_log("删除房间 {$task['room_number']} 的清洁任务");
                        $success = '清洁任务删除成功！';
                    } else {
                        $error = '清洁任务删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是更新任务状态请求，获取任务详情
$update_task = null;
$update_task_id = isset($_GET['update']) ? intval($_GET['update']) : 0;
if ($update_task_id > 0) {
    try {
        $stmt = $pdo->prepare("
            SELECT t.*, r.room_number, r.floor 
            FROM room_cleaning t
            JOIN room_info r ON t.room_id = r.id
            WHERE t.id = ?
        ");
        $stmt->execute([$update_task_id]);
        $update_task = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取任务详情失败：' . $e->getMessage();
    }
}

// 获取所有房间
try {
    $stmt = $pdo->query("
        SELECT id, room_number, floor, status 
        FROM room_info 
        ORDER BY floor, room_number
    ");
    $rooms = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房间列表失败：' . $e->getMessage();
    $rooms = [];
}

// 获取清洁人员列表
try {
    $stmt = $pdo->query("SELECT id, username FROM sys_users WHERE status = 1 ORDER BY username");
    $cleaning_staff = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取清洁人员列表失败：' . $e->getMessage();
    $cleaning_staff = [];
}

// 获取任务列表
$status_filter = isset($_GET['status']) ? intval($_GET['status']) : 0;
$floor_filter = isset($_GET['floor']) ? trim($_GET['floor']) : '';

try {
    $sql = "
        SELECT t.*, r.room_number, r.floor, u.username as cleaner_name
        FROM room_cleaning t
        JOIN room_info r ON t.room_id = r.id
        LEFT JOIN sys_users u ON t.cleaner_id = u.id
        WHERE 1=1
    ";
    $params = [];

    if ($status_filter > 0) {
        $sql .= " AND t.status = ?";
        $params[] = $status_filter;
    }

    if (!empty($floor_filter)) {
        $sql .= " AND r.floor = ?";
        $params[] = $floor_filter;
    }

    $sql .= " ORDER BY 
              t.status ASC,
              t.clean_date DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $tasks = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取任务列表失败：' . $e->getMessage();
    $tasks = [];
}

// 获取楼层列表
try {
    $stmt = $pdo->query("SELECT DISTINCT floor FROM room_info ORDER BY floor");
    $floors = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    $floors = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>客房清洁管理</title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .task-status-1 {
            background-color: #fff3cd;
        }

        .task-status-2 {
            background-color: #cfe2ff;
        }

        .task-status-3 {
            background-color: #d1e7dd;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>客房清洁管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客房管理</a> &gt; 清洁管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$update_task): ?>
                    <a href="cleaning.php?show_form=add" class="btn btn-primary">添加清洁任务</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加清洁任务表单 -->
                <h3>添加清洁任务</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="room_id">选择房间：</label>
                            <select id="room_id" name="room_id" required>
                                <option value="">-- 请选择房间 --</option>
                                <?php foreach ($rooms as $room): ?>
                                    <?php
                                    $status_texts = [
                                        1 => '空闲',
                                        2 => '已预订',
                                        3 => '已入住',
                                        4 => '清洁中',
                                        5 => '维修中',
                                        6 => '停用'
                                    ];
                                    $room_status = isset($status_texts[$room['status']]) ? $status_texts[$room['status']] : '未知';
                                    ?>
                                    <option value="<?php echo $room['id']; ?>" <?php echo ($room['status'] == 4) ? 'disabled' : ''; ?>>
                                        <?php echo $room['room_number']; ?> (<?php echo $room['floor']; ?>楼 - <?php echo $room_status; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="assigned_to">清洁人员：</label>
                            <select id="assigned_to" name="assigned_to">
                                <option value="">-- 暂不分配 --</option>
                                <?php foreach ($cleaning_staff as $staff): ?>
                                    <option value="<?php echo $staff['id']; ?>"><?php echo $staff['username']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="description">备注：</label>
                            <textarea id="description" name="description" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="cleaning.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($update_task): ?>
                <!-- 更新任务状态表单 -->
                <h3>更新清洁任务状态</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="update_status">
                        <input type="hidden" name="task_id" value="<?php echo $update_task['id']; ?>">

                        <div class="form-group">
                            <label>房间号：</label>
                            <span><?php echo $update_task['room_number']; ?> (<?php echo $update_task['floor']; ?>楼)</span>
                        </div>

                        <div class="form-group">
                            <label>清洁日期：</label>
                            <span><?php echo $update_task['clean_date']; ?></span>
                        </div>

                        <div class="form-group">
                            <label>备注：</label>
                            <textarea readonly class="form-control-plaintext" rows="3"><?php echo $update_task['remarks'] ?: '无'; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="status">更新状态为：</label>
                            <select id="status" name="status" required>
                                <option value="1" <?php echo $update_task['status'] == 1 ? 'selected' : ''; ?>>待处理</option>
                                <option value="2" <?php echo $update_task['status'] == 2 ? 'selected' : ''; ?>>处理中</option>
                                <option value="3" <?php echo $update_task['status'] == 3 ? 'selected' : ''; ?>>已完成</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="completion_notes">完成备注：</label>
                            <textarea id="completion_notes" name="completion_notes" rows="3"><?php echo isset($completion_notes) ? $completion_notes : ''; ?></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="cleaning.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="0">全部</option>
                                <option value="1" <?php echo $status_filter == 1 ? 'selected' : ''; ?>>待处理</option>
                                <option value="2" <?php echo $status_filter == 2 ? 'selected' : ''; ?>>处理中</option>
                                <option value="3" <?php echo $status_filter == 3 ? 'selected' : ''; ?>>已完成</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="floor">楼层：</label>
                            <select id="floor" name="floor">
                                <option value="">全部</option>
                                <?php foreach ($floors as $floor): ?>
                                    <option value="<?php echo $floor; ?>" <?php echo $floor_filter == $floor ? 'selected' : ''; ?>>
                                        <?php echo $floor; ?>楼
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="cleaning.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <h3>清洁任务列表</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>房间号</th>
                            <th>清洁日期</th>
                            <th>状态</th>
                            <th>清洁人员</th>
                            <th>备注</th>
                            <th>完成时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($tasks as $task): ?>
                            <tr class="task-status-<?php echo $task['status']; ?>">
                                <td><?php echo $task['id']; ?></td>
                                <td><?php echo $task['room_number']; ?> (<?php echo $task['floor']; ?>楼)</td>
                                <td><?php echo $task['clean_date']; ?></td>
                                <td>
                                    <?php
                                    switch ($task['status']) {
                                        case 1:
                                            echo '<span style="color: #ff9800;">待处理</span>';
                                            break;
                                        case 2:
                                            echo '<span style="color: #0d6efd;">处理中</span>';
                                            break;
                                        case 3:
                                            echo '<span style="color: #198754;">已完成</span>';
                                            break;
                                        default:
                                            echo '<span>未知</span>';
                                    }
                                    ?>
                                </td>
                                <td><?php echo $task['cleaner_name'] ?: '未分配'; ?></td>
                                <td>
                                    <?php
                                    // 显示备注的前30个字符
                                    echo mb_strlen($task['remarks']) > 30
                                        ? mb_substr($task['remarks'], 0, 30) . '...'
                                        : ($task['remarks'] ?: '无');
                                    ?>
                                </td>
                                <td><?php echo $task['complete_time'] ?: '-'; ?></td>
                                <td>
                                    <a href="cleaning.php?update=<?php echo $task['id']; ?>" class="btn btn-sm btn-edit">更新状态</a>

                                    <?php if ($task['status'] != 3): ?>
                                        <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此清洁任务吗？此操作不可恢复！');">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="task_id" value="<?php echo $task['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                        </form>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>

                        <?php if (empty($tasks)): ?>
                            <tr>
                                <td colspan="8" style="text-align: center;">没有找到清洁任务</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>