<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('stat_view');

// 记录访问日志
record_log('访问入住率分析页面');

// 获取当前日期和时间范围
$today = date('Y-m-d');
$current_month = date('m');
$current_year = date('Y');
$yesterday = date('Y-m-d', strtotime('-1 day'));
$last_month = date('m', strtotime('-1 month'));
$last_month_year = date('Y', strtotime('-1 month'));

// 获取筛选条件
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'custom';
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '2023-05-30';
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : '2023-06-02';
$room_type_id = isset($_GET['room_type_id']) ? intval($_GET['room_type_id']) : 0;
$compare_previous = isset($_GET['compare_previous']) ? intval($_GET['compare_previous']) : 0;

// 根据日期范围设置默认值
if ($date_range == 'week') {
    $start_date = date('Y-m-d', strtotime('-6 days'));
    $end_date = $today;
} elseif ($date_range == 'month') {
    $start_date = date('Y-m-01');
    $end_date = date('Y-m-d', strtotime('last day of this month'));
} elseif ($date_range == 'year') {
    $start_date = date('Y-01-01');
    $end_date = date('Y-12-31');
} elseif ($date_range == 'last_month') {
    $start_date = date('Y-m-01', strtotime('first day of last month'));
    $end_date = date('Y-m-d', strtotime('last day of last month'));
}

// 获取所有房型
try {
    $stmt = $pdo->query("SELECT id, type_name FROM room_types WHERE status = 1 ORDER BY id");
    $room_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房型列表失败：' . $e->getMessage();
    $room_types = [];
}

// 获取每日入住率数据
try {
    $where_clauses = ["stat_date BETWEEN ? AND ?"];
    $params = [$start_date, $end_date];

    $where_sql = implode(" AND ", $where_clauses);

    $stmt = $pdo->prepare("
        SELECT * 
        FROM report_daily_statistics 
        WHERE {$where_sql}
        ORDER BY stat_date ASC
    ");
    $stmt->execute($params);
    $daily_stats = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取每日入住率数据失败：' . $e->getMessage();
    $daily_stats = [];
}

// 获取比较数据（上一个相同时间段）
$compare_stats = [];
if ($compare_previous) {
    try {
        // 计算比较时间范围
        $date_diff = strtotime($end_date) - strtotime($start_date);
        $days_diff = round($date_diff / (60 * 60 * 24));
        $compare_end_date = date('Y-m-d', strtotime($start_date . ' -1 day'));
        $compare_start_date = date('Y-m-d', strtotime($compare_end_date . ' -' . $days_diff . ' days'));

        $stmt = $pdo->prepare("
            SELECT * 
            FROM report_daily_statistics 
            WHERE stat_date BETWEEN ? AND ?
            ORDER BY stat_date ASC
        ");
        $stmt->execute([$compare_start_date, $compare_end_date]);
        $compare_stats = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取比较数据失败：' . $e->getMessage();
        $compare_stats = [];
    }
}

// 获取按房型分类的入住率（如果选择了特定房型）
$room_type_occupancy = [];
if ($room_type_id > 0) {
    try {
        $query_dates = [];
        foreach ($daily_stats as $day) {
            $query_dates[] = $day['stat_date'];
        }

        if (!empty($query_dates)) {
            $date_placeholders = implode(',', array_fill(0, count($query_dates), '?'));

            $stmt = $pdo->prepare("
                SELECT co.checkin_date as stat_date, COUNT(*) as occupied_count,
                       (SELECT COUNT(*) FROM room_info WHERE room_type_id = ?) as total_rooms
                FROM checkin_orders co 
                JOIN room_info ri ON co.room_id = ri.id
                WHERE ri.room_type_id = ? 
                AND co.checkin_date IN ({$date_placeholders})
                AND co.status = 1
                GROUP BY co.checkin_date
                ORDER BY co.checkin_date ASC
            ");

            $params = array_merge([$room_type_id, $room_type_id], $query_dates);
            $stmt->execute($params);
            $room_occupancy_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

            // 整理数据格式
            foreach ($room_occupancy_data as $data) {
                $room_type_occupancy[$data['stat_date']] = [
                    'occupied_count' => $data['occupied_count'],
                    'total_rooms' => $data['total_rooms'],
                    'occupancy_rate' => $data['total_rooms'] > 0 ?
                        round(($data['occupied_count'] / $data['total_rooms']) * 100, 2) : 0
                ];
            }
        }
    } catch (PDOException $e) {
        $error = '获取房型入住率数据失败：' . $e->getMessage();
        $room_type_occupancy = [];
    }
}

// 计算统计数据
$avg_occupancy_rate = 0;
$max_occupancy_rate = 0;
$min_occupancy_rate = 100;
$total_days = count($daily_stats);

if ($total_days > 0) {
    $sum_occupancy = 0;
    foreach ($daily_stats as $stat) {
        $sum_occupancy += $stat['occupancy_rate'];
        if ($stat['occupancy_rate'] > $max_occupancy_rate) {
            $max_occupancy_rate = $stat['occupancy_rate'];
        }
        if ($stat['occupancy_rate'] < $min_occupancy_rate) {
            $min_occupancy_rate = $stat['occupancy_rate'];
        }
    }
    $avg_occupancy_rate = round($sum_occupancy / $total_days, 2);
}

// 计算比较期间统计数据
$compare_avg_occupancy_rate = 0;
$compare_total_days = count($compare_stats);

if ($compare_total_days > 0) {
    $compare_sum_occupancy = 0;
    foreach ($compare_stats as $stat) {
        $compare_sum_occupancy += $stat['occupancy_rate'];
    }
    $compare_avg_occupancy_rate = round($compare_sum_occupancy / $compare_total_days, 2);
}

// 计算同比变化
$change_percentage = 0;
if ($compare_avg_occupancy_rate > 0) {
    $change_percentage = round((($avg_occupancy_rate - $compare_avg_occupancy_rate) / $compare_avg_occupancy_rate) * 100, 2);
}

// 计算每周平均入住率（按周分组）
$weekly_averages = [];
foreach ($daily_stats as $stat) {
    $week_number = date('W', strtotime($stat['stat_date']));
    $week_year = date('Y', strtotime($stat['stat_date']));
    $week_key = $week_year . '-W' . $week_number;

    if (!isset($weekly_averages[$week_key])) {
        $weekly_averages[$week_key] = [
            'sum' => 0,
            'count' => 0,
            'avg' => 0,
            'start_date' => $stat['stat_date']
        ];
    }

    $weekly_averages[$week_key]['sum'] += $stat['occupancy_rate'];
    $weekly_averages[$week_key]['count']++;

    // 更新该周的结束日期
    $weekly_averages[$week_key]['end_date'] = $stat['stat_date'];
}

// 计算平均值
foreach ($weekly_averages as $week_key => $data) {
    if ($data['count'] > 0) {
        $weekly_averages[$week_key]['avg'] = round($data['sum'] / $data['count'], 2);
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>入住率分析</title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .summary-box {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .summary-item {
            flex: 1;
            min-width: 200px;
            background: #f8f9fa;
            padding: 15px;
            border-radius: 4px;
            border: 1px solid #ddd;
            text-align: center;
        }

        .summary-label {
            display: block;
            font-weight: bold;
            margin-bottom: 5px;
            color: #666;
        }

        .summary-value {
            display: block;
            font-size: 24px;
            font-weight: bold;
            color: #4CAF50;
        }

        .chart-container {
            width: 100%;
            margin-bottom: 20px;
            overflow-x: auto;
        }

        .positive-change {
            color: #28a745;
        }

        .negative-change {
            color: #dc3545;
        }

        .status-high {
            color: #28a745;
            font-weight: bold;
        }

        .status-medium {
            color: #fd7e14;
        }

        .status-low {
            color: #dc3545;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>入住率分析</h2>
            <div class="breadcrumb">
                <a href="index.php">统计分析</a> &gt; 入住率分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="date_range">时间范围：</label>
                            <select id="date_range" name="date_range" onchange="updateDateRange()">
                                <option value="week" <?php echo $date_range == 'week' ? 'selected' : ''; ?>>近7天</option>
                                <option value="month" <?php echo $date_range == 'month' ? 'selected' : ''; ?>>本月</option>
                                <option value="last_month" <?php echo $date_range == 'last_month' ? 'selected' : ''; ?>>上月</option>
                                <option value="year" <?php echo $date_range == 'year' ? 'selected' : ''; ?>>本年</option>
                                <option value="custom" <?php echo $date_range == 'custom' ? 'selected' : ''; ?>>自定义</option>
                            </select>
                        </div>
                        <div class="filter-item" id="custom_date" style="<?php echo $date_range == 'custom' ? '' : 'display:none;'; ?>">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                        </div>
                        <div class="filter-item" id="custom_date_end" style="<?php echo $date_range == 'custom' ? '' : 'display:none;'; ?>">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                        </div>
                    </div>
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="room_type_id">房型：</label>
                            <select id="room_type_id" name="room_type_id">
                                <option value="0">全部房型</option>
                                <?php foreach ($room_types as $type): ?>
                                    <option value="<?php echo $type['id']; ?>" <?php echo $room_type_id == $type['id'] ? 'selected' : ''; ?>><?php echo $type['type_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="compare_previous">比较：</label>
                            <select id="compare_previous" name="compare_previous">
                                <option value="0" <?php echo $compare_previous == 0 ? 'selected' : ''; ?>>不比较</option>
                                <option value="1" <?php echo $compare_previous == 1 ? 'selected' : ''; ?>>同比上期</option>
                            </select>
                        </div>
                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">分析</button>
                            <a href="occupancy.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 入住率概览 -->
            <div class="summary-box">
                <div class="summary-item">
                    <span class="summary-label">平均入住率</span>
                    <span class="summary-value"><?php echo $avg_occupancy_rate; ?>%</span>
                    <?php if ($compare_previous && $compare_avg_occupancy_rate > 0): ?>
                        <span class="<?php echo $change_percentage >= 0 ? 'positive-change' : 'negative-change'; ?>">
                            <?php echo $change_percentage >= 0 ? '+' : ''; ?><?php echo $change_percentage; ?>%
                        </span>
                    <?php endif; ?>
                </div>
                <div class="summary-item">
                    <span class="summary-label">最高入住率</span>
                    <span class="summary-value"><?php echo $max_occupancy_rate; ?>%</span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">最低入住率</span>
                    <span class="summary-value"><?php echo $min_occupancy_rate; ?>%</span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">统计天数</span>
                    <span class="summary-value"><?php echo $total_days; ?></span>
                </div>
            </div>

            <!-- 入住率趋势图 -->
            <h3>入住率趋势</h3>
            <div class="chart-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>日期</th>
                            <?php foreach ($daily_stats as $stat): ?>
                                <th><?php echo date('m-d', strtotime($stat['stat_date'])); ?></th>
                            <?php endforeach; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>入住率</td>
                            <?php foreach ($daily_stats as $stat): ?>
                                <td class="<?php
                                            if ($stat['occupancy_rate'] >= 80) echo 'status-high';
                                            elseif ($stat['occupancy_rate'] >= 60) echo 'status-medium';
                                            else echo 'status-low';
                                            ?>">
                                    <?php echo $stat['occupancy_rate']; ?>%
                                </td>
                            <?php endforeach; ?>
                        </tr>
                        <?php if ($compare_previous && !empty($compare_stats)): ?>
                            <tr>
                                <td>上期</td>
                                <?php
                                $i = 0;
                                foreach ($daily_stats as $stat):
                                    if (isset($compare_stats[$i])):
                                ?>
                                        <td class="<?php
                                                    if ($compare_stats[$i]['occupancy_rate'] >= 80) echo 'status-high';
                                                    elseif ($compare_stats[$i]['occupancy_rate'] >= 60) echo 'status-medium';
                                                    else echo 'status-low';
                                                    ?>">
                                            <?php echo $compare_stats[$i]['occupancy_rate']; ?>%
                                        </td>
                                    <?php
                                    else:
                                    ?>
                                        <td>-</td>
                                <?php
                                    endif;
                                    $i++;
                                endforeach;
                                ?>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 房型入住率（如果选择了特定房型） -->
            <?php if ($room_type_id > 0 && !empty($room_type_occupancy)): ?>
                <h3>房型入住率详情</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>日期</th>
                                <th>可用房间数</th>
                                <th>已入住</th>
                                <th>入住率</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($daily_stats as $stat): ?>
                                <tr>
                                    <td><?php echo $stat['stat_date']; ?></td>
                                    <?php if (isset($room_type_occupancy[$stat['stat_date']])): ?>
                                        <td><?php echo $room_type_occupancy[$stat['stat_date']]['total_rooms']; ?></td>
                                        <td><?php echo $room_type_occupancy[$stat['stat_date']]['occupied_count']; ?></td>
                                        <td class="<?php
                                                    if ($room_type_occupancy[$stat['stat_date']]['occupancy_rate'] >= 80) echo 'status-high';
                                                    elseif ($room_type_occupancy[$stat['stat_date']]['occupancy_rate'] >= 60) echo 'status-medium';
                                                    else echo 'status-low';
                                                    ?>">
                                            <?php echo $room_type_occupancy[$stat['stat_date']]['occupancy_rate']; ?>%
                                        </td>
                                    <?php else: ?>
                                        <td>-</td>
                                        <td>-</td>
                                        <td>-</td>
                                    <?php endif; ?>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>

            <!-- 周平均入住率 -->
            <?php if (!empty($weekly_averages)): ?>
                <h3>周平均入住率</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>周次</th>
                                <th>日期范围</th>
                                <th>平均入住率</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($weekly_averages as $week_key => $data): ?>
                                <tr>
                                    <td><?php echo $week_key; ?></td>
                                    <td><?php echo $data['start_date']; ?> 至 <?php echo $data['end_date']; ?></td>
                                    <td class="<?php
                                                if ($data['avg'] >= 80) echo 'status-high';
                                                elseif ($data['avg'] >= 60) echo 'status-medium';
                                                else echo 'status-low';
                                                ?>">
                                        <?php echo $data['avg']; ?>%
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>

            <!-- 详细数据列表 -->
            <h3>详细数据</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>日期</th>
                            <th>可用房间数</th>
                            <th>已住房间数</th>
                            <th>入住率</th>
                            <th>平均房价</th>
                            <th>RevPAR</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($daily_stats as $stat): ?>
                            <tr>
                                <td><?php echo $stat['stat_date']; ?></td>
                                <td><?php echo $stat['available_rooms']; ?></td>
                                <td><?php echo $stat['occupied_rooms']; ?></td>
                                <td class="<?php
                                            if ($stat['occupancy_rate'] >= 80) echo 'status-high';
                                            elseif ($stat['occupancy_rate'] >= 60) echo 'status-medium';
                                            else echo 'status-low';
                                            ?>">
                                    <?php echo $stat['occupancy_rate']; ?>%
                                </td>
                                <td>￥<?php echo number_format($stat['avg_room_rate'], 2); ?></td>
                                <td>￥<?php echo number_format($stat['avg_room_rate'] * ($stat['occupancy_rate'] / 100), 2); ?></td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (count($daily_stats) == 0): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <script>
        function updateDateRange() {
            var dateRange = document.getElementById('date_range').value;
            var customDateDiv = document.getElementById('custom_date');
            var customDateEndDiv = document.getElementById('custom_date_end');

            if (dateRange === 'custom') {
                customDateDiv.style.display = '';
                customDateEndDiv.style.display = '';
            } else {
                customDateDiv.style.display = 'none';
                customDateEndDiv.style.display = 'none';
            }
        }
    </script>
</body>

</html>